@@ -2,9 +2,9 @@ import asyncio
 from typing import Any, Dict, Optional
 import ccxt.pro as ccxt
 from ccxt import Exchange
-from ccxt import OperationFailed, OrderNotFound
+from ccxt import OperationFailed, OrderNotFound, RateLimitExceeded
 from superalgorithm.exchange.base_exchange import BaseExchange
-from superalgorithm.utils.helpers import get_now_ts
+from superalgorithm.utils.helpers import get_exponential_backoff_delay, get_now_ts
 from superalgorithm.utils.logging import log_exception, log_message
 from superalgorithm.types.data_types import (
     BalanceData,
@@ -24,6 +24,10 @@ class CCXTExchange(BaseExchange):
 
         super().__init__()
 
+        self.TRADE_LOOKBACK_SECONDS = config.get("TRADE_LOOKBACK_SECONDS", 10)
+        self.ORDER_LOOKBACK_SECONDS = config.get("ORDER_LOOKBACK_SECONDS", 600)
+        self.POLL_INTERVAL_SECONDS = config.get("POLL_INTERVAL_SECONDS", 10)
+
         self.ccxt_client: Exchange = getattr(ccxt, exchange_id)(config)
 
         self.trade_queue = asyncio.Queue()
@@ -111,25 +115,38 @@ class CCXTExchange(BaseExchange):
         API version that polls the API endpoints, loads all recent trades and and orders and processes them.
         Used as a backup in case the websocket connection fails.
         """
-        since_fetch = get_now_ts()
-        interval_seconds = 10
+        last_trade_fetch_time = get_now_ts()
+        last_order_fetch_time = get_now_ts()
 
         while True:
             try:
-                trades = await self.ccxt_client.fetchMyTrades(since=since_fetch)
-                orders = await self.ccxt_client.fetchOrders(since=since_fetch)
+                await self.fetch_and_process_trades(
+                    since_timestamp=last_trade_fetch_time
+                )
+                await self.fetch_and_process_orders(
+                    since_timestamp=last_order_fetch_time
+                )
 
-                for trade_json in trades:
-                    self.trade_queue.put_nowait(trade_json)
-
-                for order_json in orders:
-                    self.order_queue.put_nowait(order_json)
-
-                since_fetch = get_now_ts() - 1000 * interval_seconds  # 1 minute ago
+                last_trade_fetch_time = (
+                    get_now_ts() - 1000 * self.TRADE_LOOKBACK_SECONDS
+                )
+                last_order_fetch_time = (
+                    get_now_ts() - 1000 * self.ORDER_LOOKBACK_SECONDS
+                )
             except Exception as e:
-                log_exception(e, "CCXT Error fetching trades.")
+                log_exception(e, "CCXT Error syncing trades and orders.")
 
-            await asyncio.sleep(interval_seconds)
+            await asyncio.sleep(self.POLL_INTERVAL_SECONDS)
+
+    async def fetch_and_process_trades(self, since_timestamp):
+        trades = await self.ccxt_client.fetchMyTrades(since=since_timestamp)
+        for trade_json in trades:
+            self.trade_queue.put_nowait(trade_json)
+
+    async def fetch_and_process_orders(self, since_timestamp):
+        orders = await self.ccxt_client.fetchOrders(since=since_timestamp)
+        for order_json in orders:
+            self.order_queue.put_nowait(order_json)
 
     async def _create_limit_order(
         self, order: Order, params: Optional[Dict] = None
@@ -188,6 +205,7 @@ class CCXTExchange(BaseExchange):
                     order.client_order_id, order.filled, OrderStatus.CANCELED
                 )
                 return True
+
             return False
 
         except OrderNotFound:
@@ -206,6 +224,34 @@ class CCXTExchange(BaseExchange):
             )
             return False
 
+    async def _cancel_with_retry(self, order: Order) -> bool:
+        """
+        Cancels an order on the exchange and retries in case of an error.
+        """
+        max_retries = 2
+        attempt = 1
+
+        while attempt <= max_retries:
+            if await self._cancel_order(order):
+                return True
+            else:
+                delay = get_exponential_backoff_delay(attempt)
+                log_message(
+                    f"Retrying cancel order {order.server_order_id} in {delay:.2f} seconds",
+                    "INFO",
+                )
+                await asyncio.sleep(delay)
+                attempt += 1
+
+        self.order_manager.on_order_update(
+            order.client_order_id, order.filled, OrderStatus.EXPIRED
+        )
+        log_message(
+            f"Failed to cancel order {order.server_order_id} after {max_retries} attempts",
+            "ERROR",
+        )
+        return False
+
     async def _cancel_all_orders(self, pair: str = None) -> bool:
         """
         Cancels all open orders, optionally filtered by a specific trading pair.
@@ -219,8 +265,17 @@ class CCXTExchange(BaseExchange):
             if (
                 pair is None or order.pair == pair
             ) and order.order_status == OrderStatus.OPEN:
-                success.append(await self.cancel_order(order))
-                await asyncio.sleep(0.5)
+                try:
+                    result = await self._cancel_with_retry(order)
+                    success.append(result)
+                except RateLimitExceeded as e:
+                    log_exception(e, "RateLimitExceeded when cancelling all orders")
+                    await asyncio.sleep(5)
+                    result = await self._cancel_with_retry(order)
+                    success.append(result)
+                await asyncio.sleep(0.1)
+        if not all(success):
+            log_message("Some orders failed to cancel", "WARN")
         return all(success)
 
     async def _get_balances(self) -> Balances:
