@@ -1,3 +1,4 @@
+import random
 import uuid
 from datetime import datetime, timedelta
 
@@ -50,3 +51,27 @@ def get_lookback_timestamp(days: int = None, hours: int = None) -> int:
         lookback_datetime = current_datetime - timedelta(days=days, hours=hours)
 
     return int(lookback_datetime.timestamp() * 1000)
+
+
+def get_exponential_backoff_delay(
+    attempt: int, base_delay: float = 1.0, max_delay: float = 60.0
+) -> float:
+    """
+    Calculate the delay time using exponential backoff.
+
+    Args:
+        attempt (int): The current retry attempt number (starting from 1).
+        base_delay (float): The base delay time in seconds.
+        max_delay (float): The maximum delay time in seconds.
+
+    Returns:
+        float: The delay time in seconds.
+    """
+    # Calculate exponential backoff delay
+    delay = base_delay * (2 ** (attempt - 1))
+
+    # Add some jitter to avoid thundering herd problem
+    delay = delay * (0.5 + random.random() / 2)
+
+    # Ensure the delay does not exceed the maximum delay
+    return min(delay, max_delay)
